==> turgen_system-8.3.15.src.tar.bz2: turgen_system-8.3.15.src/src/turgen/plugin/csturbo/LoaderBinaryData.java <==
package turgen.plugin.csturbo;

public class LoaderBinaryData {

    public static final int[] universalTurboLoader = {
        18,600,            /*Baud*/
19,10000,132,      /*Standard data*/
0x55,0x55,0xFC,0x00,0x02,0x00,0x80,0x0E,0x80,0xA9,0x3C,0x8D,0x02,0xD3,0x4C,0x0F,0x80,0x60,0xA9,0x9F,
0x85,0x32,0xA9,0x04,0x85,0x33,0xA9,0xE9,0x85,0x34,0xA9,0x06,0x85,0x35,0xA9,0xFF,0x20,0x2F,0x80,0xB0,
0x06,0x20,0x3E,0xC6,0x4C,0x0F,0x80,0x4C,0x9F,0x04,0x85,0x36,0xA9,0x34,0x8D,0x02,0xD3,0x8D,0x03,0xD3,
0xA9,0x80,0x85,0x10,0x8D,0x0E,0xD2,0x18,0xA0,0x00,0x84,0x30,0x84,0x31,0x8C,0x0E,0xD4,0x8C,0x00,0xD4,
0x08,0xD0,0x70,0x20,0xD9,0x80,0x90,0xF9,0xA9,0x00,0x85,0x2E,0x85,0x37,0xA0,0xB4,0x20,0xD4,0x80,0x90,
0xEC,0xC0,0xD8,0x90,0xEA,0xE6,0x2E,0xD0,0xF1,0xC6,0x37,0xA0,0xD1,0x20,0xD9,0x80,0x90,0xDB,0xC0,0xDE,
0xB0,0xF5,0x20,0xD9,0x80,0x90,0x44,0xA0,0xC6,0x4C,0x9B,0xDB,
19,250,132,      /*Standard data*/
0x55,0x55,0xFA,0x80,0x28,0xD0,0x08,0xA5,0x36,0x45,0x2F,0xD0,0x37,0xF0,0x0C,0xA0,0x00,0xA5,0x2F,0x91,
0x32,0xE6,0x32,0xD0,0x02,0xE6,0x33,0xA0,0xC8,0x08,0xA9,0x01,0x85,0x2F,0x20,0xD4,0x80,0x90,0x1C,0xC0,
0xE3,0x26,0x2F,0xA0,0xC6,0x90,0xF3,0xA5,0x31,0x45,0x2F,0x85,0x31,0xA5,0x32,0xC5,0x34,0xA5,0x33,0xE5,
0x35,0x90,0xC5,0xA9,0x00,0xC5,0x31,0x68,0xA9,0xC0,0x8D,0x0E,0xD4,0x85,0x10,0x8D,0x0E,0xD2,0xA9,0x3C,
0x8D,0x02,0xD3,0x8D,0x03,0xD3,0x60,0x20,0xD9,0x80,0x90,0x24,0xA2,0x04,0xCA,0xD0,0xFD,0xA5,0x30,0x4A,
0x25,0x37,0x8D,0x1A,0xD0,0xC8,0xF0,0x13,0xA5,0x11,0xF0,0x0D,0xAD,0x0F,0xD2,0x29,0x10,0xC5,0x30,0xF0,
0xF0,0x85,0x30,0x38,0x60,0xC6,0x11,0x18,0x60,0x00,0x7E,0x4C,
19,250,132,      /*Standard data*/
0x55,0x55,0xFE,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xA9,
8,                 /*Short silence*/       
11,                /*Setup*/
32,26,12,10,0,1,1,2270,116,114,50,107,
4,768,            /*Pilot tone*/
9,                 /*Sync*/
3,588,             /*Data*/
0xFF,0x20,0xCB,0x06,0xA9,0xBD,0xA0,0x06,0x20,0x8E,0x05,0x20,0x52,0x05,0xA9,0x34,0x8D,0x02,0xD3,0x8D,
0x03,0xD3,0x20,0x3B,0x06,0x20,0x4C,0x06,0x20,0x03,0x06,0xA5,0x38,0xC9,0xB4,0x90,0x53,0xA9,0x9B,0x85,
0x34,0xA9,0x80,0x85,0x32,0x0A,0x85,0x33,0x85,0x35,0xA9,0xB7,0x20,0xA3,0x05,0x90,0xDD,0xA5,0x95,0x85,
0x32,0x18,0x65,0x97,0x85,0x34,0xA5,0x96,0x85,0x33,0x65,0x98,0x85,0x35,0xA9,0x9B,0x85,0x95,0x20,0x6A,
0x05,0xA9,0xED,0x20,0xA3,0x05,0x90,0x1A,0xA5,0x99,0x85,0x02,0xA5,0x9A,0x85,0x03,0xA9,0x3C,0x8D,0x02,
0xD3,0x8D,0x03,0xD3,0xA9,0x00,0x85,0x08,0x8D,0xF0,0x02,0x6C,0x99,0x00,0x20,0x7E,0x05,0x4C,0xA9,0x04,
0xA9,0x91,0x85,0x34,0xA9,0x80,0x85,0x32,0x0A,0x85,0x33,0x85,0x35,0x20,0x0C,0x06,0x90,0x8C,0xA5,0x8B,
0x85,0x32,0x18,0x65,0x8D,0x85,0x34,0xA5,0x8C,0x85,0x33,0x65,0x8E,0x85,0x35,0xA9,0x9B,0x85,0x8B,0x20,
0x6A,0x05,0xA9,0xFF,0x20,0x0C,0x06,0x90,0xC9,0xA5,0x8F,0x85,0x02,0xA5,0x90,0x85,0x03,0x6C,0x02,0x00,
0xA9,0x1E,0x8D,0x00,0xD2,0xA9,0xAE,0x8D,0x01,0xD2,0xA9,0x0A,0x20,0x77,0x05,0xA9,0x00,0x8D,0x00,0xD2,
0x8D,0x01,0xD2,0x60,0xA9,0x7D,0x85,0x80,0xA9,0x80,0xA0,0x00,0x20,0x8E,0x05,0xA9,0x32,0x65,0x14,0xC5,
0x14,0xD0,0xFC,0x60,0xA9,0xC0,0xA0,0x06,0x20,0x8E,0x05,0xAD,0x25,0xE4,0x48,0xAD,0x24,0xE4,0x48,0x60,
0xA2,0x00,0x8D,0x44,0x03,0x8C,0x45,0x03,0xA9,0x09,0x8D,0x42,0x03,0xA9,0xFF,0x8D,0x48,0x03,0x4C,0x56,
0xE4,0x85,0x36,0x20,0x3B,0x06,0x08,0x20,0x99,0x06,0xA4,0x39,0x20,0x9E,0x06,0x90,0xF6,0xC4,0x3A,0xB0,
0xF5,0x20,0x9E,0x06,0x90,0x46,0xA4,0x38,0x4C,0xDD,0x05,0x28,0xD0,0x08,0xA5,0x36,0x45,0x3C,0xD0,0x39,
0xF0,0x0C,0xA0,0x00,0xA5,0x3C,0x91,0x32,0xE6,0x32,0xD0,0x02,0xE6,0x33,0xA4,0x38,0xC8,0xC8,0x08,0xA9,
0x01,0x85,0x3C,0x20,0x99,0x06,0x90,0x1C,0xC4,0x39,0x26,0x3C,0xA4,0x38,0x90,0xF3,0xA5,0x31,0x45,0x3C,
0x85,0x31,0xA5,0x32,0xC5,0x34,0xA5,0x33,0xE5,0x35,0x90,0xC3,0xA9,0x00,0xC5,0x31,0x68,0xA9,0x40,0x8D,
0x0E,0xD4,0x8D,0x0E,0xD2,0x60,0x85,0x36,0x20,0x3B,0x06,0x08,0xA9,0xB0,0x85,0x38,0xA9,0xD6,0x85,0x39,
0x20,0x99,0x06,0x90,0xE3,0xA0,0x00,0x20,0x99,0x06,0x90,0xDC,0xA0,0xC8,0x20,0x9E,0x06,0x90,0xD5,0xC0,
0xD7,0xB0,0xF5,0x20,0x9E,0x06,0x90,0xCC,0xA0,0xB0,0x4C,0xDD,0x05,0xA0,0x00,0x84,0x30,0x84,0x31,0x8C,
0x0E,0xD4,0x8C,0x00,0xD4,0x8C,0x0E,0xD2,0x18,0x60,0x20,0x99,0x06,0x90,0xFB,0xA9,0x03,0x85,0x37,0xA0,
0x00,0x84,0x40,0xA2,0x03,0x20,0x99,0x06,0x90,0xEC,0xCA,0xD0,0xF8,0x98,0x4A,0x48,0x49,0xFF,0x85,0x38,
0x68,0x4A,0x48,0x49,0xFF,0x85,0x39,0x68,0x4A,0x49,0xFF,0x85,0x3A,0xA0,0x00,0x20,0x9E,0x06,0x90,0xCE,
0xA4,0x38,0x20,0x99,0x06,0x90,0xC7,0xC4,0x39,0x90,0xC3,0xE6,0x40,0xD0,0xF1,0xC6,0x37,0x10,0xC4,0xA0,
0x00,0x20,0x9E,0x06,0x90,0xB4,0x60,0x20,0x9E,0x06,0x90,0x1D,0xAD,0x0A,0xD2,0x29,0xE4,0x05,0x30,0x4A,
0x25,0x37,0x8D,0x1A,0xD0,0xC8,0xF0,0x0D,0xAD,0x0F,0xD2,0x29,0x10,0xC5,0x30,0xF0,0xF4,0x85,0x30,0x38,
0x60,0x18,0x60,0x55,0x54,0x9B,0x42,0x4F,0x4F,0x54,0x20,0x45,0x52,0x52,0x4F,0x52,0x9B,0xA9,0xDF,0x85,
0x0C,0xA9,0x06,0x85,0x0D,0xA9,0x00,0x8D,0x44,0x02,0xA9,0x01,0x85,0x09,0x20,0x74,0xE4,0xA9,0xA2,0x85,
0x0A,0xA9,0x04,0x85,0x0B,0x18,0x60,0x68,
0,                /*Narrow pulse*/
10,1              /*Long silence*/
    };

}

==> turgen_system-8.4.5.src.tar.bz2: turgen_system-8.4.5.src/src/turgen/plugin/csturbo/LoaderBinaryData.java <==
package turgen.plugin.csturbo;

public class LoaderBinaryData {

    public static final int[] universalTurboLoader = {
        18,600,            /*Baud*/
19,10000,132,      /*Standard data*/
0x55,0x55,0xFC,0x00,0x01,0x00,0x20,0x00,0x00,0xA2,0x80,0xBD,0xFF,0x03,0x9D,0x7F,0x20,0xCA,0xD0,0xF7,
0xA9,0x9F,0x85,0x32,0xA9,0x04,0x85,0x33,0xA9,0xE9,0x85,0x34,0xA9,0x06,0x85,0x35,0xA9,0xFF,0x20,0x2E,
0x20,0xB0,0x03,0x4C,0x11,0x20,0x4C,0x9F,0x04,0x85,0x36,0xA9,0x34,0x8D,0x02,0xD3,0x8D,0x03,0xD3,0xA9,
0x80,0x85,0x10,0x8D,0x0E,0xD2,0x18,0xA0,0x00,0x84,0x30,0x84,0x31,0x8C,0x0E,0xD4,0x8C,0x00,0xD4,0x08,
0xD0,0x70,0x20,0xD8,0x20,0x90,0xF9,0xA9,0x00,0x85,0x2E,0x85,0x37,0xA0,0xB4,0x20,0xD3,0x20,0x90,0xEC,
0xC0,0xD8,0x90,0xEA,0xE6,0x2E,0xD0,0xF1,0xC6,0x37,0xA0,0xD1,0x20,0xD8,0x20,0x90,0xDB,0xC0,0xDE,0xB0,
0xF5,0x20,0xD8,0x20,0x90,0x44,0xA0,0xC6,0x4C,0x9A,0x20,0xCC,
19,300,132,      /*Standard data*/
0x55,0x55,0xFE,0x28,0xD0,0x08,0xA5,0x36,0x45,0x2F,0xD0,0x37,0xF0,0x0C,0xA0,0x00,0xA5,0x2F,0x91,0x32,
0xE6,0x32,0xD0,0x02,0xE6,0x33,0xA0,0xC8,0x08,0xA9,0x01,0x85,0x2F,0x20,0xD3,0x20,0x90,0x1C,0xC0,0xE3,
0x26,0x2F,0xA0,0xC6,0x90,0xF3,0xA5,0x31,0x45,0x2F,0x85,0x31,0xA5,0x32,0xC5,0x34,0xA5,0x33,0xE5,0x35,
0x90,0xC5,0xA9,0x00,0xC5,0x31,0x68,0xA9,0xC0,0x8D,0x0E,0xD4,0x85,0x10,0x8D,0x0E,0xD2,0xA9,0x3C,0x8D,
0x02,0xD3,0x8D,0x03,0xD3,0x60,0x20,0xD8,0x20,0x90,0x24,0xA2,0x04,0xCA,0xD0,0xFD,0xA5,0x30,0x4A,0x25,
0x37,0x8D,0x1A,0xD0,0xC8,0xF0,0x13,0xA5,0x11,0xF0,0x0D,0xAD,0x0F,0xD2,0x29,0x10,0xC5,0x30,0xF0,0xF0,
0x85,0x30,0x38,0x60,0xC6,0x11,0x18,0x60,0x00,0x00,0x7D,0x0C,
8,                 /*Short silence*/       
11,                /*Setup*/
32,26,12,10,0,1,1,2270,116,114,50,107,
4,768,            /*Pilot tone*/
9,                 /*Sync*/
3,588,             /*Data*/
0xFF,0x20,0xCB,0x06,0xA9,0xBD,0xA0,0x06,0x20,0x8E,0x05,0x20,0x52,0x05,0xA9,0x34,0x8D,0x02,0xD3,0x8D,
0x03,0xD3,0x20,0x3B,0x06,0x20,0x4C,0x06,0x20,0x03,0x06,0xA5,0x38,0xC9,0xB4,0x90,0x53,0xA9,0x9B,0x85,
0x34,0xA9,0x80,0x85,0x32,0x0A,0x85,0x33,0x85,0x35,0xA9,0xB7,0x20,0xA3,0x05,0x90,0xDD,0xA5,0x95,0x85,
0x32,0x18,0x65,0x97,0x85,0x34,0xA5,0x96,0x85,0x33,0x65,0x98,0x85,0x35,0xA9,0x9B,0x85,0x95,0x20,0x6A,
0x05,0xA9,0xED,0x20,0xA3,0x05,0x90,0x1A,0xA5,0x99,0x85,0x02,0xA5,0x9A,0x85,0x03,0xA9,0x3C,0x8D,0x02,
0xD3,0x8D,0x03,0xD3,0xA9,0x00,0x85,0x08,0x8D,0xF0,0x02,0x6C,0x99,0x00,0x20,0x7E,0x05,0x4C,0xA9,0x04,
0xA9,0x91,0x85,0x34,0xA9,0x80,0x85,0x32,0x0A,0x85,0x33,0x85,0x35,0x20,0x0C,0x06,0x90,0x8C,0xA5,0x8B,
0x85,0x32,0x18,0x65,0x8D,0x85,0x34,0xA5,0x8C,0x85,0x33,0x65,0x8E,0x85,0x35,0xA9,0x9B,0x85,0x8B,0x20,
0x6A,0x05,0xA9,0xFF,0x20,0x0C,0x06,0x90,0xC9,0xA5,0x8F,0x85,0x02,0xA5,0x90,0x85,0x03,0x6C,0x02,0x00,
0xA9,0x1E,0x8D,0x00,0xD2,0xA9,0xAE,0x8D,0x01,0xD2,0xA9,0x0A,0x20,0x77,0x05,0xA9,0x00,0x8D,0x00,0xD2,
0x8D,0x01,0xD2,0x60,0xA9,0x7D,0x85,0x80,0xA9,0x80,0xA0,0x00,0x20,0x8E,0x05,0xA9,0x32,0x65,0x14,0xC5,
0x14,0xD0,0xFC,0x60,0xA9,0xC0,0xA0,0x06,0x20,0x8E,0x05,0xAD,0x25,0xE4,0x48,0xAD,0x24,0xE4,0x48,0x60,
0xA2,0x00,0x8D,0x44,0x03,0x8C,0x45,0x03,0xA9,0x09,0x8D,0x42,0x03,0xA9,0xFF,0x8D,0x48,0x03,0x4C,0x56,
0xE4,0x85,0x36,0x20,0x3B,0x06,0x08,0x20,0x99,0x06,0xA4,0x39,0x20,0x9E,0x06,0x90,0xF6,0xC4,0x3A,0xB0,
0xF5,0x20,0x9E,0x06,0x90,0x46,0xA4,0x38,0x4C,0xDD,0x05,0x28,0xD0,0x08,0xA5,0x36,0x45,0x3C,0xD0,0x39,
0xF0,0x0C,0xA0,0x00,0xA5,0x3C,0x91,0x32,0xE6,0x32,0xD0,0x02,0xE6,0x33,0xA4,0x38,0xC8,0xC8,0x08,0xA9,
0x01,0x85,0x3C,0x20,0x99,0x06,0x90,0x1C,0xC4,0x39,0x26,0x3C,0xA4,0x38,0x90,0xF3,0xA5,0x31,0x45,0x3C,
0x85,0x31,0xA5,0x32,0xC5,0x34,0xA5,0x33,0xE5,0x35,0x90,0xC3,0xA9,0x00,0xC5,0x31,0x68,0xA9,0x40,0x8D,
0x0E,0xD4,0x8D,0x0E,0xD2,0x60,0x85,0x36,0x20,0x3B,0x06,0x08,0xA9,0xB0,0x85,0x38,0xA9,0xD6,0x85,0x39,
0x20,0x99,0x06,0x90,0xE3,0xA0,0x00,0x20,0x99,0x06,0x90,0xDC,0xA0,0xC8,0x20,0x9E,0x06,0x90,0xD5,0xC0,
0xD7,0xB0,0xF5,0x20,0x9E,0x06,0x90,0xCC,0xA0,0xB0,0x4C,0xDD,0x05,0xA0,0x00,0x84,0x30,0x84,0x31,0x8C,
0x0E,0xD4,0x8C,0x00,0xD4,0x8C,0x0E,0xD2,0x18,0x60,0x20,0x99,0x06,0x90,0xFB,0xA9,0x03,0x85,0x37,0xA0,
0x00,0x84,0x40,0xA2,0x03,0x20,0x99,0x06,0x90,0xEC,0xCA,0xD0,0xF8,0x98,0x4A,0x48,0x49,0xFF,0x85,0x38,
0x68,0x4A,0x48,0x49,0xFF,0x85,0x39,0x68,0x4A,0x49,0xFF,0x85,0x3A,0xA0,0x00,0x20,0x9E,0x06,0x90,0xCE,
0xA4,0x38,0x20,0x99,0x06,0x90,0xC7,0xC4,0x39,0x90,0xC3,0xE6,0x40,0xD0,0xF1,0xC6,0x37,0x10,0xC4,0xA0,
0x00,0x20,0x9E,0x06,0x90,0xB4,0x60,0x20,0x9E,0x06,0x90,0x1D,0xAD,0x0A,0xD2,0x29,0xE4,0x05,0x30,0x4A,
0x25,0x37,0x8D,0x1A,0xD0,0xC8,0xF0,0x0D,0xAD,0x0F,0xD2,0x29,0x10,0xC5,0x30,0xF0,0xF4,0x85,0x30,0x38,
0x60,0x18,0x60,0x55,0x54,0x9B,0x42,0x4F,0x4F,0x54,0x20,0x45,0x52,0x52,0x4F,0x52,0x9B,0xA9,0xDF,0x85,
0x0C,0xA9,0x06,0x85,0x0D,0xA9,0x00,0x8D,0x44,0x02,0xA9,0x01,0x85,0x09,0x20,0x74,0xE4,0xA9,0xA2,0x85,
0x0A,0xA9,0x04,0x85,0x0B,0x18,0x60,0x68,
0,                /*Narrow pulse*/
10,1              /*Long silence*/
    };

}
